@@ -111,6 +111,7 @@
              'WPS/Result/MultiLineString.js',
              'WPS/Result/MultiPolygon.js',
              'WPS/Result/Group.js',
+             'WPS/Result/Viewport.js',
              'WPS/Result/ProcessDescription.js',
              'WPS/Result/WPSPDGeometry.js',
              'WPS/Result/WPSPDPoint.js',
@@ -119,7 +120,8 @@
              'WPS/Result/WPSPDMultiPoint.js',
              'WPS/Result/WPSPDMultiLineString.js',
              'WPS/Result/WPSPDMultiPolygon.js',
-             'WPS/Result/WPSPDMarker.js'
+             'WPS/Result/WPSPDMarker.js',
+             'WPS/Result/WPSPDStyledFeatureCollection.js'
             ]; // etc.
         }
 
