@@ -21,6 +21,9 @@
  */
 
 WPS.GEOM_POINT_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#Point';
+WPS.GEOM_MULTI_POINT_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#MultiPoint';
 WPS.GEOM_LINE_STRING_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#LineString';
+WPS.GEOM_MULTI_LINE_STRING_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#MultiLineString';
 //WPS.GEOM_BOX_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#Envelope';
-WPS.GEOM_POLYGON_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#Polygon';
\ No newline at end of file
+WPS.GEOM_POLYGON_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#Polygon';
+WPS.GEOM_MULTI_POLYGON_URI = 'http://schemas.opengis.net/gml/3.1.1/base/gml.xsd#MultiPolygon';
\ No newline at end of file
